##  Managing Views
In the **Views** section on the dashboard configuration page, you can:
  * Create up to 15 views.
  * Add views to custom groups, with a maximum of 10 groups.
  * Duplicate views to create views with similar configurations.
  * Show, hide, edit, reorder, or delete groups and individual views. Hover over a group or view, then select the option you need.
  * Adjust the default view by customizing inventory filters.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio47eda45009244cdda367c2f803778341_LowRes.png)
Options for Managing a View
